@@ -89,7 +89,7 @@ TYPES = {
 		"icon"	: "stock_news",
 		"description": (_("News from %s") % "<i>%(publisher)s</i>" ) + "\n<b>%(name)s</b>",
 		"snippet": True,
-		"category": "web",
+		"category": "news",
 		"extra": {"publisher":("dc:publisher",), "identifier": ("dc:identifier",)},
 		},
 	"Note"		: {
@@ -98,12 +98,12 @@ TYPES = {
 		"icon"	:"stock_notes",
 		"description": _("Note: %s") % "<b>%(name)s</b>",
 		"snippet": True,
-		"category": "documents",
+		"category": "notes",
 		},
 	"IMLog"		: {
 		"name"	: ("fixme:speakingto",),
 		"extra" : {"client": ("fixme:client",)},
-		"action": "beagle-imlogviewer --client %(client)s %(uri)s",
+		"action": "beagle-imlogviewer --client %(client)s --highlight-search '%(text)s' %(uri)s",
 		"icon"	: "im",
 		"description": _("With %s") % "<b>%(name)s</b>",
 		"snippet": True,
@@ -120,7 +120,7 @@ TYPES = {
 		"name"	: ("dc:title",), # FIX-BEAGLE bug #330053, dc:title returns as None even though it _is_ set
 		"action": lambda d: gnome.url_show(d["uri"]),
 		"icon"	: "stock_bookmark",
-		"description": (_("Open History Item %s") % "<i>%(name)s</i>") + "\n%(uri)s",
+		"description": (_("Open History Item %s") % "<i>%(name)s</i>") + "\n%(escaped_uri)s",
 		"category": "web",
 		},
 }
@@ -149,6 +149,8 @@ class BeagleLiveMatch (deskbar.Match.Match):
 		if not callable(action) and action.startswith("beagle-imlogviewer"):
 			# Strip the uti descriptor, because imlogviewer takes a local path
 			self.result["uri"] = gnomevfs.get_local_path_from_uri(self.result["uri"])
+			# Escape text since we use '%(text)s' as parameter
+			self.result["text"] = self.result["text"].replace("'", "\\'")
 		
 		# Load the correct icon
 		
@@ -304,7 +306,11 @@ class BeagleLiveHandler(deskbar.Handler.SignallingHandler):
 							pass
 							
 					if val != None:
-						result[prop] = cgi.escape(val)
+						if prop == "uri" or prop == "identifier":
+							result[prop] = val
+							result["escaped_"+prop] = cgi.escape(val)
+						else:
+							result[prop] = cgi.escape(val)
 						break
 					
 				if val == None:
