@@ -1,8 +1,8 @@
 from gettext import gettext as _
 from gettext import ngettext
-
+from deskbar.defs import VERSION
 import wnck, gtk
-import deskbar.Handler, deskbar
+import deskbar.Handler, deskbar.Match, deskbar
 import re
 import cgi
 
@@ -14,10 +14,10 @@ HANDLERS = {
 		"categories" : {
 			"windows"	: {
 				"name": _("Windows"),
-				"nest": lambda n: ngettext("%s more window", "%s more windows", n),
-				"threshold": 10
 				}
-			}
+			},
+		"version": VERSION,
+			
 		}
 	}
 
