@@ -3,8 +3,10 @@ from os.path import join
 import struct
 import gtk, gtk.gdk, gtk.glade, gobject, gconf
 import deskbar, deskbar.Utils
-from deskbar.ui.ModuleListView import ModuleListView
-from deskbar import CUEMIAC_UI_NAME, ENTRIAC_UI_NAME
+from deskbar.updater.NewStuffUpdater import NewStuffUpdater
+from deskbar.ui.ModuleListView import ModuleListView, WebModuleListView
+from deskbar.ModuleList import WebModuleList
+from deskbar import CUEMIAC_UI_NAME, ENTRIAC_UI_NAME, WINDOW_UI_NAME
 
 MAXINT = 2 ** ((8 * struct.calcsize('i')) - 1) - 1
 
@@ -133,10 +135,20 @@ class AccelEntry( gobject.GObject ):
 class DeskbarPreferencesUI:
 	def __init__(self, applet, module_loader, module_list):
 		self.module_list = module_list
+		self.web_module_list = WebModuleList()
 		self.module_loader = module_loader
 		self.glade = gtk.glade.XML(join(deskbar.SHARED_DATA_DIR, "prefs-dialog.glade"))
-
+		
 		self.dialog = self.glade.get_widget("preferences")
+		
+		# Since newstuff is optional we have to check if self.newstuff is None each time we use it
+		self.newstuff = None
+		try:
+			self.newstuff = NewStuffUpdater(self.dialog, module_loader, module_list, self.web_module_list)
+			self.newstuff.connect('ready', self.on_newstuff_ready)
+		except Exception, e:
+			print '** Warning: Couldn\'t start newstuff updater:', e
+			
 		# Retreive current values
 		self.width = deskbar.GCONF_CLIENT.get_int(applet.prefs.GCONF_WIDTH)
 		self.expand = deskbar.GCONF_CLIENT.get_bool(applet.prefs.GCONF_EXPAND)
@@ -160,6 +172,7 @@ class DeskbarPreferencesUI:
 		self.moduleview = ModuleListView(module_list)
 		self.moduleview.connect ("row-toggled", self.on_module_toggled, module_loader)
 		self.moduleview.get_selection().connect("changed", self.on_module_selected)
+		self.module_list.connect('row-changed', lambda list, path, iter: self.on_module_selected(self.moduleview.get_selection()))
 		container.add(self.moduleview)
 
 		self.default_info = self.glade.get_widget("default_info")
@@ -172,10 +185,11 @@ class DeskbarPreferencesUI:
 		self.other_info_label.set_alignment(0.0, 0.5)
 		self.other_info_label.set_justify(gtk.JUSTIFY_LEFT)
 		self.other_info.pack_start(self.other_info_label, expand=True, fill=True)
-		self.more_button = gtk.Button(_("_More..."))
+		
+		self.more_button = self.glade.get_widget("more")
+		self.more_button.set_sensitive(False)
 		self.more_button.connect("clicked", self.on_more_button_clicked)
 		self.more_button_callback = None
-		self.other_info.pack_start(self.more_button, expand=False, fill=False)
 
 		self.info_area = self.glade.get_widget("info_area")
 		self.old_info_message = None
@@ -187,6 +201,29 @@ class DeskbarPreferencesUI:
 		self.cuemiac_ui_radio.connect ("toggled", self.on_ui_changed, applet)
 		self.ui_change_id = deskbar.GCONF_CLIENT.notify_add(applet.prefs.GCONF_UI_NAME, lambda x, y, z, a: self.on_config_ui(z.value))
 		
+		self.use_selection = deskbar.GCONF_CLIENT.get_bool(applet.prefs.GCONF_USE_SELECTION)
+		self.use_selection_box = self.glade.get_widget("use_selection")
+		self.use_selection_box.connect('toggled', self.on_use_selection_toggled, applet)
+		self.use_selection_id = deskbar.GCONF_CLIENT.notify_add(applet.prefs.GCONF_USE_SELECTION, lambda x, y, z, a: self.on_config_use_selection(z.value))
+		
+		container = self.glade.get_widget("newhandlers")
+		self.webmoduleview = WebModuleListView(self.web_module_list)
+		self.webmoduleview.get_selection().connect("changed", self.on_webmodule_selected)
+		self.web_module_list.connect('row-changed', lambda list, path, iter: self.on_webmodule_selected(self.webmoduleview.get_selection()))
+		
+		container.add(self.webmoduleview)
+		
+		self.install = self.glade.get_widget("install")
+		self.check = self.glade.get_widget("check")
+		self.update = self.glade.get_widget("update")
+		
+		self.check.connect('clicked', self.on_check_handlers)
+		self.check.set_sensitive(False)
+		self.update.connect('clicked', self.on_update_handler)
+		self.update.set_sensitive(False)
+		self.install.connect('clicked', self.on_install_handler)
+		self.install.set_sensitive(False)
+		
 		self.sync_ui()
 		
 	def show_run_hide(self):
@@ -196,6 +233,8 @@ class DeskbarPreferencesUI:
 	
 	def on_dialog_response(self, dialog, response):	
 		self.dialog.destroy()
+		if self.newstuff != None:
+			self.newstuff.close()
 		
 		deskbar.GCONF_CLIENT.notify_remove(self.width_notify_id)
 		deskbar.GCONF_CLIENT.notify_remove(self.expand_notify_id)
@@ -225,6 +264,12 @@ class DeskbarPreferencesUI:
 		elif self.ui_name == CUEMIAC_UI_NAME:
 			self.cuemiac_ui_radio.set_active (True)
 			self.set_width_settings_sensitive(False)
+		elif self.ui_name == WINDOW_UI_NAME:
+			self.cuemiac_ui_radio.set_active (True)
+			self.set_ui_settings_sensitive(False)
+			self.set_width_settings_sensitive(False)
+		
+		self.use_selection_box.set_active(self.use_selection)
 			
 	def set_width_settings_sensitive(self, sensitive):
 		if sensitive and not self.expand:
@@ -236,6 +281,11 @@ class DeskbarPreferencesUI:
 			
 		self.use_all_width_radio.set_sensitive(sensitive)
 		self.fixed_width_radio.set_sensitive(sensitive)
+
+	def set_ui_settings_sensitive(self, sensitive):
+		self.cuemiac_ui_radio.set_sensitive(sensitive)
+		self.completion_ui_radio.set_sensitive(sensitive)
+
 		
 	def on_config_width(self, value):
 		if value != None and value.type == gconf.VALUE_INT:
@@ -256,8 +306,16 @@ class DeskbarPreferencesUI:
 		if value != None and value.type == gconf.VALUE_STRING:
 			self.ui_name = value.get_string ()
 			self.sync_ui()
+	
+	def on_config_use_selection(self, value):
+		if value != None and value.type == gconf.VALUE_BOOL:
+			self.use_selection = value.get_bool()
+			self.sync_ui()
 			
 	def on_ui_changed (self, sender, applet):
+		if self.ui_name == WINDOW_UI_NAME:
+			# You cannot change to or from window ui
+			return
 		if self.completion_ui_radio.get_active ():
 			deskbar.GCONF_CLIENT.set_string(applet.prefs.GCONF_UI_NAME, ENTRIAC_UI_NAME)
 		elif self.cuemiac_ui_radio.get_active ():
@@ -274,6 +332,9 @@ class DeskbarPreferencesUI:
 				deskbar.GCONF_CLIENT.set_string(applet.prefs.GCONF_KEYBINDING, accel_name)
 		return False
 
+	def on_use_selection_toggled(self, toggle, applet):
+		deskbar.GCONF_CLIENT.set_bool(applet.prefs.GCONF_USE_SELECTION, toggle.get_active())
+		
 	def on_more_button_clicked(self, button):
 		if self.more_button_callback != None:
 			self.more_button_callback(self.dialog)
@@ -283,7 +344,14 @@ class DeskbarPreferencesUI:
 		if module_context != None:
 			self.check_requirements(module_context)
 			gobject.timeout_add(1000, self.poll_requirements, module_context)
+			
+		# Check if we can update
+		self.update.set_sensitive(module_context != None and module_context.update_infos[0])				
 	
+	def on_webmodule_selected(self, selection):
+		module_context = self.webmoduleview.get_selected_module_context()
+		self.install.set_sensitive(module_context != None and not module_context.installing)
+		
 	def poll_requirements(self, module_context):
 		try:
 			if module_context != self.moduleview.get_selected_module_context():
@@ -322,17 +390,39 @@ class DeskbarPreferencesUI:
 			self.other_info_label.set_text(message)
 			self.info_area.add(self.other_info)
 			self.other_info.show_all()
-			if self.more_button_callback != None:
-				self.more_button.show()
-			else:
-				self.more_button.hide()
+			self.more_button.set_sensitive(self.more_button_callback != None)
+
 	
 	def on_module_toggled(self, moduleview, context, loader):
 		if (context.enabled):
 			loader.stop_module_async (context)
 		else:
 			loader.initialize_module_async (context)
-				
+	
+	def on_newstuff_ready(self, newstuff):
+		self.check.set_sensitive(True)
+		self.install.set_sensitive(True)
+		
+	def on_check_handlers(self, button):
+		#Update all handlers
+		if self.newstuff != None:
+			self.newstuff.check_all()
+		
+	def on_update_handler(self, button):
+		module_context = self.moduleview.get_selected_module_context()
+		if module_context != None:
+			# Trigger module update
+			if self.newstuff != None:
+				self.newstuff.update(module_context)
+			button.set_sensitive(False)
+		
+	def on_install_handler(self, button):
+		# Install the selected new handler
+		module_context = self.webmoduleview.get_selected_module_context()
+		if module_context != None:
+			if self.newstuff != None:
+				self.newstuff.install(module_context)
+			button.set_sensitive(False)
 			
 def show_preferences(applet, loader, model):
 	DeskbarPreferencesUI(applet, loader, model).show_run_hide()
